@@ -37,7 +37,7 @@ version of rosdep that works against tarballs of released stacks.
 
 import yaml
 
-from .model import RosdepDatabase, InvalidRosdepData
+from .model import RosdepDatabase, InvalidData
 
 ROSDEP_YAML = 'rosdep.yaml'
 
@@ -60,7 +60,7 @@ class RosdepLoader:
         try:
             return yaml.load(yaml_contents)
         except yaml.YAMLError as e:
-            raise InvalidRosdepData("Invalid YAML in [%s]: %s"%(origin, e), origin=origin)
+            raise InvalidData("Invalid YAML in [%s]: %s"%(origin, e), origin=origin)
 
     def load_view(self, view_name, rosdep_db, verbose=False):
         """
@@ -70,9 +70,10 @@ class RosdepLoader:
         :param view_name: name of ROS stack to load, ``str``
         :param rosdep_db: database to load stack data into, :class:`RosdepDatabase`
 
-        :raises: :exc:`InvalidRosdepData`
+        :raises: :exc:`InvalidData`
+        :raises: :exc:`rospkg.ResourceNotFound` if view cannot be located
         """
-        raise NotImplementedError()
+        raise NotImplementedError(view_name, rosdep_db, verbose) #pychecker
 
     def get_loadable_resources(self):
         raise NotImplementedError()
@@ -84,7 +85,7 @@ class RosdepLoader:
         """
         :raises: :exc:`rospkg.ResourceNotFound` if *resource_name* cannot be found.
         """
-        raise NotImplementedError()
+        raise NotImplementedError(resource_name, implicit) #pychecker
     
     def get_view_key(self, resource_name):
         """
@@ -95,4 +96,4 @@ class RosdepLoader:
         :returns: Name of view that *resource_name* is in, ``None`` if no associated view.
         :raises: :exc:`rospkg.ResourceNotFound` if *resource_name* cannot be found.
         """
-        raise NotImplementedError() 
+        raise NotImplementedError(resource_name) 
