@@ -344,12 +344,12 @@ def test_parse_sources_data():
         except InvalidData as e:
             pass
         
-def test_create_default_matcher():
+def test_DataSourceMatcher_create_default():
     distro_name = rospkg.distro.current_distro_codename()
     os_detect = rospkg.os_detect.OsDetect()
     os_name, os_version, os_codename = os_detect.detect_os()
 
-    matcher = rosdep2.sources_list.create_default_matcher()
+    matcher = rosdep2.sources_list.DataSourceMatcher.create_default()
 
     # matches full
     os_data_source = rosdep2.sources_list.DataSource('yaml', 'http://fake/url', [distro_name, os_name, os_codename])
